#[non_exhaustive]pub enum ErrorKind {
}Expand description
Stable category of a telemetry encoding or decoding error.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
LengthOverflow
The encoded snapshot length cannot be represented.
OutputTooSmall
The output buffer is too small.
OutputLengthMismatch
The output buffer does not have the exact encoded length.
Wire(WireError)
The wire container is invalid.
UnsupportedSchema(u16)
The telemetry schema version is unsupported.
MissingSection(u16)
A required section is missing.
DuplicateSection(u16)
A section appears more than once.
MalformedSection(u16)
A section payload is malformed.
IntegerOverflow
A decoded integer cannot fit in the target type.
InvalidUtf8(u16)
A section contains invalid UTF-8.
UnknownEventKind(u8)
An allocation event kind is unknown.
UnknownSliceKind(u8)
A topology slice kind is unknown.
UnknownRuntimeEventKind(u8)
A runtime event kind is unknown.